## 可用工具列表

### ⚠️ 重要说明
**股票代码格式规范**:所有涉及股票代码的参数(`symbol` 或 `code`)必须使用标准格式
- 对于`symbol`参数:必须使用**市场代码(2个大写字母)+ 股票数字(6位数字)**格式,例如:`SZ000001`、`SH600000`
- 对于`code`参数:仅使用**6位纯数字**格式,例如:`000001`、`600000`
- **注意**:用户输入股票名称时,必须先转换为对应的代码格式

---

### 🔍 实体提取与因子分析

#### ✅ extract_query
**功能**:从查询中提取金融实体,包括股票、债券、基金、加密货币、指数、商品、ETF等类型,并查找对应的代码
**参数**:
  - `query` (必填, string): 需要提取实体的查询文本
**返回**:查询中出现的金融实体,包括其类型和代码

#### ✅ company_factor
**功能**:构建公司整体估值的金融因子逻辑图,综合所有业务板块的因子分析
**参数**:
  - `name` (必填, string): 公司名称
  - `code` (必填, string): 股票代码,6位纯数字格式

---

### 📈 同花顺专项数据工具

#### ✅ crawl_ths_company
**功能**:获取股票的公司资料信息
**数据范围**:详细情况、高管介绍、发行相关、参控股公司
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_holder
**功能**:获取股票的股东研究信息
**数据范围**:股东人数、十大流通股东、十大股东、十大债券持有人、控股层级关系
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_operate
**功能**:获取股票的经营分析信息
**数据范围**:主营介绍、运营业务数据、主营构成分析、主要客户及供应商、董事会经营评述、产品价格
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_equity
**功能**:获取股票的股本结构信息
**数据范围**:解禁时间表、总股本构成、A股结构图、历次股本变动
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_capital
**功能**:获取股票的资本运作信息
**数据范围**:募集资金来源、项目投资、收购兼并、股权投资、参股IPO、股权转让、关联交易、质押解冻
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_finance
**功能**:获取股票的财务分析信息
**数据范围**:财务诊断、财务指标、指标变动说明、资产负债构成、财务报告、杜邦分析
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_worth
**功能**:获取股票的盈利预测信息
**数据范围**:业绩预测、业绩预测详表、研报评级
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_news
**功能**:获取股票的新闻公告信息
**数据范围**:新闻与股价联动、公告列表、热点新闻列表、研报列表
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_concept
**功能**:获取股票的概念题材信息
**数据范围**:常规概念、其他概念、题材要点、概念对比
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_position
**功能**:获取股票的主力持仓信息
**数据范围**:机构持股汇总、机构持股明细、被举牌情况、IPO获配机构
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_bonus
**功能**:获取股票的分红融资信息
**数据范围**:分红诊断、分红情况、增发机构获配明细、增发概况、配股概况
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_event
**功能**:获取股票的公司大事信息
**数据范围**:高管持股变动、股东持股变动、担保明细、违规处理、机构调研、投资者互动
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000

#### ✅ crawl_ths_field
**功能**:获取股票的行业对比信息
**数据范围**:行业地位、行业新闻
**参数**:
  - `query` (必填, string): 用户查询意图,描述需要获取的具体信息类型
  - `code` (必填, string): 股票代码,6位纯数字格式,例如:000001、600000


#### ✅ dashscope_search
**功能**:使用搜索关键词从互联网检索相关信息
**参数**:
  - `query` (必填, string): 搜索关键词

#### ✅ bailian_web_parser
**功能**:网页内容解析工具,根据提供的网页地址获取网页内容并进行格式化
**参数**:
  - `url` (必填, string): 需要获取内容的网页地址
  - `format` (可选, string): 期待返回的格式内容,默认返回markdown格式